==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/en/templates.php <==
<?php
regGS("The template $1 is in use and can not be deleted.", "The template $1 is in use and can not be deleted.");
regGS("The folder could not be deleted.", "The folder could not be deleted.");
regGS("The directory must be empty", "The directory must be empty");
regGS("Create new folder", "Create new folder");
regGS("Upload template", "Upload template");
regGS("Creating new folder", "Creating new folder");
regGS("You do not have the right to create new folders.", "You do not have the right to create new folders.");
regGS("The folder $1 could not be created", "The folder $1 could not be created");
regGS("A file or folder having the name $1 already exists", "A file or folder having the name $1 already exists");
regGS("You do not have the right to delete templates.", "You do not have the right to delete templates.");
regGS("Are you sure you want to delete the folder $1 from $2?", "Are you sure you want to delete the folder $1 from $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Are you sure you want to delete the template $1 from folder $2?");
regGS("Deleting template", "Deleting template");
regGS("Deleting folder", "Deleting folder");
regGS("Template $1 was deleted", "Template $1 was deleted");
regGS("Delete folder", "Delete folder");
regGS("Folders", "Folders");
regGS("No folders.", "No folders.");
regGS("Files", "Files");
regGS("No templates.", "No templates.");
regGS("Uploading template", "Uploading template");
regGS("File", "File");
regGS("Create new template", "Create new template");
regGS("Creating new template", "Creating new template");
regGS("Duplicate template", "Duplicate template");
regGS("Edit template", "Edit template");
regGS("The template $1 has been created.", "The template $1 has been created.");
regGS("Do you want to edit the template ?", "Do you want to edit the template ?");
regGS("The template $1 could not be created.", "The template $1 could not be created.");
regGS("Template $1 was changed", "Template $1 was changed");
regGS("New template $1 was created", "New template $1 was created");
regGS("Template $1 was duplicated into $2", "Template $1 was duplicated into $2");
regGS("Template charset", "Template charset");
regGS("Select a language/character set", "Select a language/character set");
regGS("All languages", "All languages");
regGS("You do not have the right to modify templates.", "You do not have the right to modify templates.");
regGS("Invalid template file $1", "Invalid template file $1");
regGS("You do not have the right to create folders.", "You do not have the right to create folders.");
regGS("You do not have the right to upload templates.", "You do not have the right to upload templates.");
regGS("You do not have the right to create templates.", "You do not have the right to create templates.");
regGS("Duplicate file", "Duplicate file");
regGS("Delete file", "Delete file");
regGS("Unable to save the template '$1' to the path '$2'.", "Unable to save the template '$1' to the path '$2'.");
regGS("Please check if the user '$1' has permission to write in this directory.", "Please check if the user '$1' has permission to write in this directory.");
regGS("Unable to delete the template '$1' in the path '$2'.", "Unable to delete the template '$1' in the path '$2'.");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/en/templates.php <==
<?php 
regGS("Template ID:", "Template ID:");
regGS("Template ID", "Template ID");
regGS("Template $1 no longer exists!", "Template $1 no longer exists!");
regGS("New template $1 created", "New template $1 created");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "If the file you specified is a text file, you can convert its character set using the dropdown below.");
regGS("Directory $1 was deleted", "Directory $1 was deleted");
regGS("Directory $1 created.", "Directory $1 created.");
regGS("You must select a file to upload.", "You must select a file to upload.");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".");
regGS("Unable to save the file '$1' to the path '$2'.", "Unable to save the file '$1' to the path '$2'.");
regGS("Replace file:", "Replace file:");
regGS("Replace", "Replace");
regGS("File \"$1\" uploaded.", "File \"$1\" uploaded.");
regGS("File \"$1\" replaced.", "File \"$1\" replaced.");
regGS("The folder name can't be '..' or '.'", "The folder name can't be '..' or '.'");
regGS("The template '$1' was saved successfully.", "The template '$1' was saved successfully.");
regGS("The template $1 is in use and can not be deleted.", "The template $1 is in use and can not be deleted.");
regGS("Create new folder", "Create new folder");
regGS("Upload template", "Upload template");
regGS("You do not have the right to create new folders.", "You do not have the right to create new folders.");
regGS("A file or folder having the name $1 already exists", "A file or folder having the name $1 already exists");
regGS("You do not have the right to delete templates.", "You do not have the right to delete templates.");
regGS("Are you sure you want to delete the folder $1 from $2?", "Are you sure you want to delete the folder $1 from $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Are you sure you want to delete the template $1 from folder $2?");
regGS("Template $1 was deleted", "Template $1 was deleted");
regGS("Delete folder", "Delete folder");
regGS("Folders", "Folders");
regGS("No folders.", "No folders.");
regGS("Files", "Files");
regGS("No templates.", "No templates.");
regGS("File", "File");
regGS("Create new template", "Create new template");
regGS("Duplicate template", "Duplicate template");
regGS("Edit template", "Edit template");
regGS("The template $1 could not be created.", "The template $1 could not be created.");
regGS("Template $1 was changed", "Template $1 was changed");
regGS("Template $1 was duplicated into $2", "Template $1 was duplicated into $2");
regGS("Template charset", "Template charset");
regGS("Select a language/character set", "Select a language/character set");
regGS("All languages", "All languages");
regGS("You do not have the right to modify templates.", "You do not have the right to modify templates.");
regGS("Invalid template file $1", "Invalid template file $1");
regGS("You do not have the right to create folders.", "You do not have the right to create folders.");
regGS("You do not have the right to upload templates.", "You do not have the right to upload templates.");
regGS("You do not have the right to create templates.", "You do not have the right to create templates.");
regGS("Duplicate file", "Duplicate file");
regGS("Delete file", "Delete file");
regGS("Please check if the user '$1' has permission to write in this directory.", "Please check if the user '$1' has permission to write in this directory.");
?>
